==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs(
    public val all:
    Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("evvwuuyuhrximgwt")
    public suspend
    fun all(`value`: Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("qhhotvfbnlxmkltj")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("yorsipqapskalurk")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ivwbrslsujehrvdg")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qmixrndmmqvlekuw")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("uidkwfpyokerodlx")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("momftuoftmiqfyqf")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("fpxephcxwkxhftdl")
    public suspend
    fun all(`value`: RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("pnnhfqvrnullythx")
    public suspend
    fun all(argument: suspend RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("msdmakfvmuytyelo")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("ujppnwqsxknugghi")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("mwjiecqlyimjunvq")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("stdvmtldmgvvwxvj")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build(): RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs =
        RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs(
            all = all,
            excludedCookies = excludedCookies,
            includedCookies = includedCookies,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property excludedCookies
 * @property includedCookies
 */
public data class RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs(
    public val all: Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null,
    public val excludedCookies: Output<List<String>>? = null,
    public val includedCookies: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .excludedCookies(excludedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .includedCookies(includedCookies?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>? =
        null

    private var excludedCookies: Output<List<String>>? = null

    private var includedCookies: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("iuhbtwrnfndhctks")
    public suspend fun all(`value`: Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("capiiwwxtiorygxx")
    public suspend fun excludedCookies(`value`: Output<List<String>>) {
        this.excludedCookies = value
    }

    @JvmName("tqgspgutslrjmpgx")
    public suspend fun excludedCookies(vararg values: Output<String>) {
        this.excludedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("medrxcllcywstmla")
    public suspend fun excludedCookies(values: List<Output<String>>) {
        this.excludedCookies = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("dwncqeoxerqpiybq")
    public suspend fun includedCookies(`value`: Output<List<String>>) {
        this.includedCookies = value
    }

    @JvmName("nhlsrnujnuapwgjk")
    public suspend fun includedCookies(vararg values: Output<String>) {
        this.includedCookies = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("smmvgbgtbrhhhgas")
    public suspend fun includedCookies(values: List<Output<String>>) {
        this.includedCookies = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("klmgamewyjghgenj")
    public suspend fun all(`value`: RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("ieuafonicjhpejgs")
    public suspend fun all(argument: suspend RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("yiegxybdhnvtsvhi")
    public suspend fun excludedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("wpqgtpkxtmddirdn")
    public suspend fun excludedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.excludedCookies = mapped
    }

    /**
     * @param value
     */
    @JvmName("ouccrqdomecxtvsi")
    public suspend fun includedCookies(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    /**
     * @param values
     */
    @JvmName("mmuesnrhdmpgqluf")
    public suspend fun includedCookies(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedCookies = mapped
    }

    internal fun build(): RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs = RuleGroupRuleStatementRegexMatchStatementFieldToMatchCookiesMatchPatternArgs(
        all = all,
        excludedCookies = excludedCookies,
        includedCookies = includedCookies,
    )
}
